# liltab

## Dev
You need to have Python 3.10 and pip.

To get dependencies run: 
```
make get_dependencies
```

To format and check code with linter run:
```
make prepare_code
```

Run tests using following: 
```
make run_tests
```
